#define Version "0.23"
/*
    (w) Joerg Schulenburg, 2004-2007
       
    H = -t (sum_<ij>sigma c_isigma cj_sigma + h.c) // nn-hopping
       + U sum_i n_iu*n_id                         // on-site-repulsion
       + V sum_<ij> n_i*n_j                        // inter-site-repulsion
       + sum_ij Vh/|Ri-Rj| h_i*h_j                 // hole-hole-repulsion
       
    h_i = (1-niu*nid) = double-hole repulsion, hole = empty site

    v0.23 - new format
    v0.22 - change format for hole-hole repulsion
    v0.21 - add next nearest hopping t2 (rest of parameters shifted by 1)
    v0.20 - version code rearranged
    v0.1  - initial version  Jul.2004
       
    tested for spinpack-2.22p1 with 
     - ./m_tU 8 >daten.def
     - daten.i:
       - param=1,0,10,0,0,1,0.5,0.3333333333.0.125
       # double defined bounds for distance |i-j|=4 therfore 0.125=0.25/2
       - nud=3,3  sym_ud=-1  sym_k=-10000
     - config.h
       - #define Nv 4  // 4 is used as flag to switch Hamiltonian

 test 1:
   param=0.00001,0,10,0,0,1,0.5,0.333333333333,0.125 nud=3,3 sym_ud=-1 sym_k=-1000
   0U2+4V4+4V5+4V6+6V7 = 4*1+4*0.5+4*0.3333+6*0.125 = 6+4/3+3/4 = 8.083333
         nud=3,3 t1=0 E=+0.25000000 = 1*1/4                  |.uud.ddu> Ouchni=0.25
 test 2: nud=3,3 t1=1 E=-4.64654788                                           -4.6465479
 test 3: nud=1,1 t1=0 E=+8.08333333 = 4*1+4*1/2+4*1/3+3*1/4  |...u...d> 
 test 4: nud=1,1 t1=1 E=+4.50235033                                            4.5023503
 test 5:
     - ./m_tU 10 >daten.def
     - daten.i:
       - param=1,0,10,0,0,1,0.5,0.3333333333.0.25,0.1 # V/5 twice
       - nud=2,2  sym_ud=-1  sym_k=-10000 # E0=  0.49214574    1s PM-2600MHz
       - sym_k= -2 0   -1000     # n1=      E0=  0.49214574 translation
       - sym_k= -2 0 1 -1000     # n1=56    E0=  0.49214574 translation + reflection
 # sym_k=-1000: uu and dd is wrong for SBase & Sud & Sz=0, use mean value!
 i-j  0  0 uu  0.002086 dd  0.397914 hh  0.600993 (uu+dd)/2  0.200000 = 1/5
 i-j  0  1 uu  0.000000 dd  0.000145 hh  0.261778 (uu+dd)/2  0.000072
 i-j  0  2 uu  0.000000 dd  0.002876 hh  0.352994 (uu+dd)/2  0.001438
 i-j  0  3 uu  0.000002 dd  0.027462 hh  0.358566 (uu+dd)/2  0.013732
 i-j  0  4 uu  0.000033 dd  0.096640 hh  0.349752 (uu+dd)/2  0.048336
 i-j  0  5 uu  0.000190 dd  0.145494 hh  0.365735 (uu+dd)/2  0.072842
 i-j  0  6 uu  0.000516 dd  0.096157 hh  0.349752 (uu+dd)/2  0.048336 same as 0-4
 ...       [ --- build mean value! --- ]
 i-j  1  2 uu  0.000000 dd  0.000144 hh  0.261778 same as 0-1 !
  v2.23: <B(l,l+1)>              l= 0 -0.642523 (sym_k=-2 -1000)    OK (F.Ouchni)
         <B(l,l+1) B(l+r,l+r+1)> r= 1  0.299550 (sym_k=-2 0 -1000)  OK (F.Ouchni)
         <B(l,l+1)>              l= 0 -0.642523 (sym_k=-2 0 1 -1000) OK
 test 6:
     - ./m_tU 12 >daten.def
     - daten.i:
       - param=1,0,10,0,0,1,0.5,0.3333333333.0.25,0.2,0.08333333333 # V/6 twice
       - nud=3,3  sym_ud=-1  sym_k=-10000 # E0= -2.54533067   19s PM-600MHz
       - sym_k= -2 0   -1000     # n1=2037  E0= -2.54533067    2s using translation
       - sym_k= -2 0 0 -1000     # n1=1086  E0= -2.54533067    2s using translation + reflection
       - nud=4,4                 # n1=122e3 E0= -5.94513752  116s
       - sym_k= -2 0 0 -1000     # n1=5181  E0= -5.94513752   11s
       - nud=6,6 sym_k=-2 0 1    # n1=18e3  E0= -3.08585397   47s
*/
#include <stdlib.h>
#include <stdio.h>


int initvars(int n0,int pbc){
   int i,j,nn,nw;
   nn=n0;
   nw=n0*(n0/2);
   printf("# def-file, tU-chain\n"
	"# automaticly generated by m_tU v%s n0=%d PBC\n"
	"#===edge=== %d 0 0 999\n"
	"#+++model+++\n"
	"# NN=Number_of_sites Nw=Number_of_bonds Nv=Number_of_bonds(2)\n"
	"%d %d 0\n"
        "# s  X  Y  Z p_e p_U (s=siteindex  (X Y Z)=position  p=index"
        " of parameter)\n",
     Version, n0, n0, nn, nw);
   for(i=0;i<n0;i++)
     printf(" %2d %2d 0 0  e4 u3\n",  i, i );
   printf("# Bond s1 s2 p_t p_J [h# V#] \n");
   /* t1 t2 U3 e4 V5 h6 h7 ...   */
   for(j=1;j<=n0/2;j++) /* possible distances */
   for(i=0;i<n0;i++)
     printf(" %2d %2d %2d  t%d %cj0%s h%d\n",
      (j-1)*n0+i,           /* index bound */
      i,(i+j)%n0,           /* connected two sites */
      ((j>=1 && j<=2)?j:0), /* hopping p_t */
      ((i+j>=n0)?'+':' '),  /* PBC-J0 */
      ((j>=1 && j<=1)?" V5":"   "), /* repulsion p_V */
      5+j);                     /* hole-hole h# */
   printf("#---model---\n");
   return 0;
}


main(int argc,char *argv[]){
   if(argc!=2){
     fprintf(stderr,
       " generate daten.def for an tUV-chain v%s\n"
       " use: m_tU ?length?\n"
       "   length: 1..32  chain length in unit cells\n", Version);
     exit(1);
   }
   initvars(atoi(argv[1]),1);
}
