#ifndef Model_c
#define Title "models/mcuo3.h Cu-O(3) chain 4Cu" 
#define Sym       1	/* x x 7 x x x x x x Symmetrien */
#define Sud       1
#define CM(JJ,tJ,tU) tU	  /* Heisenberg-,  t-J- or  Hubbard-model */
/* =========================== Gitter =========================== *
   ..   O   O   O   O             O=2 O orbits 2,4, 3,5, 1,7
       /|\ /|\ /|\ /|\ /          C=2 Cu orbits 0,6
       -C-O-C-O-C-O-C-O-..  y
       \|/ \|/ \|/ \|/ \    |
   ..   O   O   O   O       +--x
 * ============================================================== */
#define N0 4		/* number of Cu-sites (4) */
#define Nc 2		/* number of orbitals per Cu-site (2) */
#define No 2		/* number of orbitals per O-site  (2) */
#define NN (N0*(Nc+3*No))
#define Nw (N0*7*(Nc*No))
#define Ne NN		/* (a b) means (a over b) = a!/((a-b)!b!) */
#define Nv (N0*(4+0*8*Nc*No))	/* (Nc 2) + 3(No 2) + ... */
#define IFham1(x) x
#define IFham2(x)
#define noSBase 1		/* SBase/noSBase = with/without symmetry */ 
#endif
#if Model_c
  /*  i=site 0..NN, d=translation rc=i+vec_d */
int site_move(int i,int dx,int dy,...){ return 0;} /* not used */
int initvars(){ int i,j,jw,jn,jv,k;
  jw=Nw/N0;jn=NN/N0;jv=Nv/N0;
  /* position ? */
  /*     3,5
       / |   \   /
       --0,6--1,7--
       \ |   /   \
         2,4
  */
  for(i=0;i<N0;i++){ j=((i+1<N0) ? i+1 : 0); /* nice! next Cu site */ 
    k=i*jw;
    iw[k][0]=i*jn+0; iw[k][1]=i*jn+1; wt[k]=1; k++; /* dxy0-px1 - */
    iw[k][0]=i*jn+0; iw[k][1]=i*jn+2; wt[k]=1; k++; /* dxy0-py2 - */
    iw[k][0]=i*jn+0; iw[k][1]=i*jn+3; wt[k]=1; k++; /* dxy0-py3 - */
    iw[k][0]=i*jn+0; iw[k][1]=j*jn+1; wt[k]=1; k++; /* dxy0-px8 - */
    iw[k][0]=i*jn+0; iw[k][1]=i*jn+7; wt[k]=2; k++; /* dxy0-py7 + */
    iw[k][0]=i*jn+0; iw[k][1]=i*jn+4; wt[k]=2; k++; /* dxy0-px4 + */
    iw[k][0]=i*jn+0; iw[k][1]=i*jn+5; wt[k]=2; k++; /* dxy0-px5 + */
    iw[k][0]=i*jn+0; iw[k][1]=j*jn+7; wt[k]=2; k++; /* dxy0-py7 + */
    iw[k][0]=i*jn+1; iw[k][1]=i*jn+2; wt[k]=3; k++; /* px1-py2 + */
    iw[k][0]=i*jn+1; iw[k][1]=i*jn+3; wt[k]=4; k++; /* px1-py3 - */
    iw[k][0]=j*jn+1; iw[k][1]=i*jn+2; wt[k]=4; k++; /* px8-py2 - */
    iw[k][0]=j*jn+1; iw[k][1]=i*jn+3; wt[k]=3; k++; /* px8-py3 + */
    iw[k][0]=i*jn+7; iw[k][1]=i*jn+4; wt[k]=3; k++; /* py7-px4 + */
    iw[k][0]=i*jn+7; iw[k][1]=i*jn+5; wt[k]=4; k++; /* py7-px5 - */
    iw[k][0]=j*jn+7; iw[k][1]=i*jn+4; wt[k]=4; k++; /* py8-px4 - */
    iw[k][0]=j*jn+7; iw[k][1]=i*jn+5; wt[k]=3; k++; /* py8-px5 + */

    iw[k][0]=i*jn+1; iw[k][1]=i*jn+4; wt[k]=5; k++; /* px1-px4 - */
    iw[k][0]=i*jn+1; iw[k][1]=i*jn+5; wt[k]=5; k++; /* px1-px5 - */
    iw[k][0]=j*jn+1; iw[k][1]=i*jn+4; wt[k]=5; k++; /* px8-px4 - */
    iw[k][0]=j*jn+1; iw[k][1]=i*jn+5; wt[k]=5; k++; /* px8-px5 - */
    iw[k][0]=i*jn+7; iw[k][1]=i*jn+2; wt[k]=5; k++; /* py7-py2 - */
    iw[k][0]=i*jn+7; iw[k][1]=i*jn+3; wt[k]=5; k++; /* py7-py3 - */
    iw[k][0]=j*jn+7; iw[k][1]=i*jn+2; wt[k]=5; k++; /* py8-py2 - */
    iw[k][0]=j*jn+7; iw[k][1]=i*jn+3; wt[k]=5; k++; /* py8-py3 - */
    iw[k][0]=i*jn+6; iw[k][1]=i*jn+1; wt[k]=6; k++; /* dz0-px1 + */
    iw[k][0]=i*jn+6; iw[k][1]=i*jn+2; wt[k]=7; k++; /* dz0-py2 - */
    iw[k][0]=i*jn+6; iw[k][1]=i*jn+3; wt[k]=6; k++; /* dz0-py3 + */
    iw[k][0]=i*jn+6; iw[k][1]=j*jn+1; wt[k]=7; k++; /* dz0-px8 - */
  }
  nu=N0/2;nd=N0/2+N0%2;		/* 1 per Cu */
  for(i=0;i<N0;i++){ j=((i+1<N0) ? i+1 : 0); /* nice! next Cu site */
    we[i*jn+0]= 9;  wu[i*jn+0]=13;			/* Cu dxy */
    we[i*jn+1]=10;  wu[i*jn+1]=14;			/* O1 px  */
    we[i*jn+2]=10;  wu[i*jn+2]=14;			/* O2 px */
    we[i*jn+3]=10;  wu[i*jn+3]=14;			/* O3 px */
    we[i*jn+4]=11;  wu[i*jn+4]=14;			/* O4 py */
    we[i*jn+5]=11;  wu[i*jn+4]=14;			/* O5 py */
    we[i*jn+7]=11;  wu[i*jn+4]=14;			/* O7 py */
    we[i*jn+6]=12;  wu[i*jn+5]=13;			/* Cu dz */
    k=i*jv;
    iw2[k][0]=1+i*jn;iw2[k][1]=7+i*jn;wu2[k]=16;wj2[k]=19;k++;/* O1 px-pz */
    iw2[k][0]=2+i*jn;iw2[k][1]=4+i*jn;wu2[k]=16;wj2[k]=19;k++;/* O2 px-pz */
    iw2[k][0]=3+i*jn;iw2[k][1]=5+i*jn;wu2[k]=16;wj2[k]=19;k++;/* O3 px-pz */
    iw2[k][0]=0+i*jn;iw2[k][1]=6+i*jn;wu2[k]=17;wj2[k]=20;k++;/* Cu-Cu dxy-dz */
    /* Cu-O, O-O vorlaeufig weggelassen */
  }
/*
  N0=4,No=Nc=2 k=000000 ud=-1 E0 
  N0=4,No=Nc=2 k=000004 ud=-1 E0 
  N0=4,No=Nc=2 k=000010 ud=-1 E0 
  N0=4,No=Nc=2 k=000014 ud=-1 E0 
  N0=4,No=Nc=2 k=000000 ud=+1 E0 
  N0=4,No=Nc=2 nosym          E0 
 */
    numpara=15 /* 22 */ ;
    para[ 0]= 0.0;	/* immer 0 */
    para[ 1]=-0.8;	/* t_Cu-O -px.dxy */
    para[ 2]= 0.2;	/* t_Cu-O  py.dxy */
    para[ 3]= 0.6;	/* t_O-O   px.py  */
    para[ 4]=-0.6;	/* t_O-O  -px.py  */
    para[ 5]=-0.4;	/* t_O-O  -px.px  */
    para[ 6]= 0.3;	/* t_Cu-O  dz.px */
    para[ 7]=-0.3;	/* t_Cu-O -dz.px */
    para[ 8]= 0.0;	/* reserve */
    para[ 9]=-0.5;	/* e_Cu dxy */
    para[10]= 2.6;	/* e_O  px */
    para[11]= 2.7;	/* e_O  py */
    para[12]= 0.2;	/* e_Cu dz */
    para[13]= 8.0;	/* U0_Cu dxy */
    para[14]= 4.0;	/* U0_O  px,py */
    para[15]= 0.0;	/* --- */
    para[16]= 3.2;	/* O   U  = U0 + 2 JH */
    para[17]= 6.4;	/* Cu  U  = U0 + 2 JH */
    para[18]= 0.56;	/* Upd */
    para[19]=-0.4;	/* O  JH = U0/10 */
    para[20]=-0.8;	/* Cu JH = U0/10 */
    para[21]=-1.2;	/* Kpd */
    x_p=0;return 0;}
#endif 


